@@ -1,39 +1,31 @@
 #' Methods for objects of class \code{"MTDest"}
 #'
 #' @description
-#' Printing, summarizing, and extracting information from EM fits of Mixture
-#'  Transition Distribution (MTD) models.
+#' Methods for objects returned by \code{MTDest()} – EM fits of Mixture Transition
+#' Distribution models. Note that \code{"MTDest"} objects inherit from class \code{"MTD"}
+#' (they have class \code{c("MTDest", "MTD")}), and several methods for \code{"MTD"}
+#' also work on \code{"MTDest"} objects by inheritance. The methods documented
+#' here are specific to EM fits, providing diagnostics and summaries of the estimation.
 #'
 #' @details
-#' These methods handle objects returned by \code{\link{MTDest}} (class \code{"MTDest"}):
+#' These methods handle objects returned by \code{\link{MTDest}} (class \code{c("MTDest","MTD")}):
 #' \itemize{
 #'   \item \code{print.MTDest()} displays a compact summary of the fitted model:
 #'    the lag set (\code{S}), the state space (\code{A}), the final
 #'     log-likelihood, and, if available, the number of EM updates performed.
 #'
-#'   \item \code{summary.MTDest()} collects key components of the object into a
-#'   readable summary list (class \code{"summary.MTDest"}), including lambdas,
-#'   transition matrices, independent distribution (if present), log-likelihood,
-#'    oscillations (if available), and iteration diagnostics.
-#'
-#'   \item \code{print.summary.MTDest()} prints the summary in a readable format,
-#'    including lambdas, transition matrices, independent distribution,
-#'     log-likelihood, oscillations (if available), and iteration diagnostics
-#'      (if available).
-#'
-#'   \item \code{coef.MTDest()} extracts the estimated mixture weights
-#'    (\code{lambdas}), the list of transition matrices (\code{pj}), and the
-#'     independent distribution (\code{p0}).
+#'   \item \code{summary.MTDest()} computes and prints a detailed summary of the
+#'   key components of the object, including lambdas, transition matrices,
+#'   independent distribution (if present), log-likelihood, and
+#'   (if available) oscillations and iteration diagnostics.
 #'
 #'   \item \code{logLik.MTDest()} returns the log-likelihood as an object of class
 #'    \code{"logLik"}, with attributes \code{df} (number of free parameters
 #'     under the multimatrix model) and \code{nobs} (effective sample size).
 #' }
 #'
-#' @param x An object of class \code{"MTDest"} or \code{"summary.MTDest"},
-#'  depending on the method.
-#' @param object An object of class \code{"MTDest"} (used by summary, coef, and
-#'  logLik methods).
+#' @param x An object of class \code{"MTDest"} (for \code{print.MTDest(x, ...)}).
+#' @param object An object of class \code{"MTDest"}.
 #' @param ... Further arguments passed to or from other methods (ignored).
 #'
 #' @return
@@ -41,17 +33,17 @@
 #'  \item{\code{print.MTDest}}{Invisibly returns the \code{"MTDest"} object, after
 #'     displaying its lag set, state space, final log-likelihood, and iteration
 #'     count (if available).}
-#'   \item{\code{print.summary.MTDest}}{Invisibly returns the \code{"summary.MTDest"} object,
-#'     after displaying its contents: lambdas; transition matrices; independent
-#'     distribution; log-likelihood; oscillations (if available); and
-#'     iteration diagnostics (if available).}
-#'   \item{\code{summary.MTDest}}{An object of class \code{"summary.MTDest"}.}
-#'   \item{\code{coef.MTDest}}{A list with estimated \code{lambdas}, \code{pj}, and \code{p0}.}
+#'   \item{\code{summary.MTDest}}{Invisibly returns a named list with fields:
+#'         \code{call}, \code{S}, \code{A}, \code{lambdas}, \code{pj},
+#'         \code{p0} (or \code{NULL}),\code{logLik}, \code{oscillations},
+#'         \code{iterations}, \code{lastComputedDelta} and \code{deltaLogLik}.
+#'         The same information is printed to the console in a readable format.}
 #'   \item{\code{logLik.MTDest}}{ An object of class \code{"logLik"} with attributes
 #'     \code{df} (number of free parameters) and \code{nobs} (effective sample size).}
 #' }
 #'
-#' @seealso \code{\link{MTDest}}, \code{\link{as.MTD}}
+#' @seealso \code{\link{MTDest}}, \code{\link{as.MTD}}, \code{\link{MTD-methods}},
+#' \code{\link{oscillation}}, \code{\link{perfectSample}}, \code{\link{probs}}
 #'
 #' @examples
 #' \dontrun{
@@ -69,7 +61,7 @@
 #' fit <- MTDest(X, S = c(1, 3), init = init, iter = TRUE)
 #' print(fit)
 #' summary(fit)
-#' coef(fit)
+#' coef(fit) # Works by inheritance
 #' logLik(fit)
 #' BIC(fit)
 #' }
@@ -79,25 +71,25 @@ NULL
 
 #' @exportS3Method print MTDest
 print.MTDest <- function(x, ...) {
+  lg <- lags(x)
+  A  <- states(x)
+
   cat("An object of class 'MTDest' (EM estimation of MTD model)\n")
-  cat("  Lags (-S):", paste(-x$S, collapse = ", "), "\n")
-  cat("  State space (A):", paste(x$A, collapse = ", "), "\n")
+  cat("  Lags (-S):", fmt_vec(lg), "\n")
+  cat("  State space (A):", fmt_vec(A), "\n")
   cat("  Log-likelihood:", format(x$logLik, digits = 6), "\n")
   if (!is.null(x$iterations)) {
     cat("  Number of updates:", x$iterations, "\n")
   }
   cat("  Use summary() for full description.\n")
-  cat("  Accessors: lambdas(), pj(), p0(), lags(), S(), states().\n")
-  cat("  Methods: coef(), probs(), as.MTD(), logLik(), plot().\n")
   invisible(x)
 }
 
+# ------------------------- summary.MTDest ---------------------------------
+
 #' @exportS3Method summary MTDest
 summary.MTDest <- function(object, ...) {
-  stopifnot(inherits(object, "MTDest"))
 
-  lenA <- length(object$A)
-  lenS <- length(object$S)
   indep <- any(object$p0 != 0)
 
   out <- list(
@@ -113,65 +105,61 @@ summary.MTDest <- function(object, ...) {
     lastComputedDelta = if (!is.null(object$lastComputedDelta)) object$lastComputedDelta else NA_real_,
     deltaLogLik = if (!is.null(object$deltaLogLik)) object$deltaLogLik else NA_real_
   )
-  class(out) <- "summary.MTDest"
-  out
+  print_MTDest_summary(out) # prints summary (side effect)
+  invisible(out)
 }
-
-#' @exportS3Method print summary.MTDest
-print.summary.MTDest <- function(x, ...) {
+#' Format and print the MTDest summary (internal helper)
+#' @keywords internal
+#' @noRd
+print_MTDest_summary <- function(object) {
   cat("Summary of EM estimation for MTD model:\n")
 
-  if (!is.null(x$call)) cat("\nCall:\n"); if (!is.null(x$call)) print(x$call)
+  if (!is.null(object$call)) {
+    cat("\nCall:\n")
+    print(object$call)
+  }
 
-  cat("\nLags (-S):", paste(-x$S, collapse = ", "),
-      "\nState space (A):", paste(x$A, collapse = ", "), "\n")
+  cat("\nLags (-S):", paste(-object$S, collapse = ", "),
+      "\nState space (A):", paste(object$A, collapse = ", "), "\n")
 
   cat("\nlambdas (weights):\n")
-  print(x$lambdas)
+  print(object$lambdas)
 
-  if (!is.null(x$p0)) {
+  if (!is.null(object$p0)) {
     cat("\nIndependent distribution p0:\n")
-    print(x$p0)
+    print(object$p0)
   } else {
     cat("\nIndependent distribution p0: (none)\n")
   }
 
   cat("\nTransition matrices pj (one per lag):\n")
-  for (i in seq_along(x$pj)) {
-    cat(sprintf(" \n pj for lag j = %s:\n", -x$S[i]))
-    print(x$pj[[i]])
+  for (i in seq_along(object$pj)) {
+    cat(sprintf(" \n pj for lag j = %s:\n", -object$S[i]))
+    print(object$pj[[i]])
   }
 
-  cat("\nLog-likelihood:", format(x$logLik, digits = 6), "\n")
+  cat("\nLog-likelihood:", format(object$logLik, digits = 6), "\n")
 
-  if (!is.null(x$oscillations)) {
+  if (!is.null(object$oscillations)) {
     cat("\nOscillations:\n")
-    print(x$oscillations)
+    print(object$oscillations)
   }
 
-  if (!is.na(x$iterations) || !is.na(x$lastComputedDelta)) {
+  if (!is.na(object$iterations) || !is.na(object$lastComputedDelta)) {
     cat("\nIterations Report:\n")
-    cat("Number of updates:", x$iterations, "\n")
-    cat("Last compared difference of logLik:", format(x$lastComputedDelta, digits = 6), "\n")
+    cat("Number of updates:", object$iterations, "\n")
+    cat("Last compared difference of logLik:",
+        format(object$lastComputedDelta, digits = 6), "\n")
   }
 
-  invisible(x)
+  invisible(object)
 }
 
-#' @exportS3Method coef MTDest
-coef.MTDest <- function(object, ...) {
-  stopifnot(inherits(object, "MTDest"))
-  out <- list(
-    lambdas = object$lambdas,
-    pj      = object$pj,
-    p0      = object$p0
-  )
-  out
-}
+
+# --------------------------- logLik.MTD ----------------------------------
 
 #' @exportS3Method logLik MTDest
 logLik.MTDest <- function(object, ...) {
-  stopifnot(inherits(object, "MTDest"))
 
   indep <- any(object$p0 != 0)
 
