@@ -1,22 +1,32 @@
-#' Accessors for objects of classes \code{"MTD"}, \code{"MTDest"}, and \code{"hdMTD"}
+#' Accessors for objects of classes \code{"MTD"}, \code{"MTDest"}, and/or \code{"hdMTD"}
 #'
 #' @description
-#' Public accessors that expose model components without relying on the internal
+#' Public accessors that expose object components without relying on the internal
 #' list structure. These accessors are available for \code{"MTD"} (model
-#' objects), \code{"MTDest"} (EM fits), and \code{"hdMTD"} (lag selection),
-#' except \code{transitP()} which only applies to \code{"MTD"}.
+#' objects), \code{"MTDest"} (EM fits), and/or \code{"hdMTD"} (lag selection).
 #'
 #' @details
 #' Returned lag sets follow the package convention and are shown as negative
 #' integers via \code{lags()} (elements of \eqn{\mathbb{Z}^-}). For convenience,
 #' positive-index accessors are also provided:
-#' \code{Lambda()} for \code{"MTD"} objects and \code{S()} for \code{"MTDest"} and
-#' \code{"hdMTD"} objects (elements of \eqn{\mathbb{N}^+}). Internally, lags may
-#' be stored as positive integers in \code{Lambda} or \code{S}.
+#' \code{Lambda()} for \code{"MTD"} objects and \code{"MTDest"} fits, and
+#' \code{S()} for \code{"MTDest"} and \code{"hdMTD"} objects
+#' (elements of \eqn{\mathbb{N}^+}).
 #'
-#' For computing the global transition matrix of an EM fit the user can first
-#' coerce the MTDest object into an MTD using \link{as.MTD} and then access the
-#' matrix with \code{transitP(as.MTD(object))}.
+#' The function \code{transitP()} returns the global transition matrix, i.e., a
+#' convex combination of the independent distribution \code{p0} and the
+#' lag-specific transition matrices \code{pj}, weighted by \code{lambdas}.
+#'
+#' @note
+#' Naming conventions reflect the conceptual distinction:
+#' \itemize{
+#'   \item \code{Lambda}: The true (known) relevant lag set in \code{"MTD"} models
+#'   \item \code{S}: An estimated or candidate lag set in \code{"MTDest"} and
+#'         \code{"hdMTD"} objects
+#' }
+#' Most accessors for \code{"MTD"} also work for \code{"MTDest"} via inheritance.
+#' When needed (e.g., \code{transitP()}), a specific \code{"MTDest"} method
+#' is provided.
 #'
 #' @param object An object of class \code{"MTD"}, \code{"MTDest"} or \code{"hdMTD"}
 #'  (as supported by each accessor).
@@ -27,16 +37,15 @@
 #'   \item{\code{p0(object)}}{A numeric probability vector for the independent component.}
 #'   \item{\code{lambdas(object)}}{A numeric vector of mixture weights that sums to 1.}
 #'   \item{\code{lags(object)}}{The lag set (elements of \eqn{\mathbb{Z}^-}).}
-#'   \item{\code{Lambda(object)}}{For \code{"MTD"}, the lag set as positive integers
+#'   \item{\code{Lambda(object)}}{The set of relevant lags as positive integers
 #'    (elements of \eqn{\mathbb{N}^+}).}
-#'   \item{\code{S(object)}}{For \code{"MTDest"} and \code{"hdMTD"}, the lag set as
-#'    positive integers (elements of \eqn{\mathbb{N}^+}).}
+#'   \item{\code{S(object)}}{For \code{"MTDest"} and \code{"hdMTD"}, the set of
+#'   candidate/estimated lags as positive integers (elements of \eqn{\mathbb{N}^+}).}
 #'   \item{\code{states(object)}}{The state space.}
-#'   \item{\code{transitP(object)}}{For \code{"MTD"} objects only, the global
-#'   transition matrix \eqn{P}. Not available for \code{"MTDest"}.}
+#'   \item{\code{transitP(object)}}{The global transition matrix \eqn{P}.}
 #' }
 #'
-#' @seealso \code{\link{MTDmodel}}, \code{\link{MTDest}}, \code{\link{hdMTD}}, \code{\link{as.MTD}}
+#' @seealso \code{\link{MTDmodel}}, \code{\link{MTDest}}, \code{\link{hdMTD}}.
 #'
 #' @examples
 #' \dontrun{
@@ -49,7 +58,7 @@
 #' X <- perfectSample(m, N = 800)
 #' fit <- MTDest(X, S = c(1, 3), init = coef(m))
 #' pj(fit); p0(fit); lambdas(fit); lags(fit); S(fit); states(fit)
-#' transitP(as.MTD(fit))
+#' transitP(fit)
 #' ## For lag selection:
 #' S_hat <- hdMTD(X, d = 5, method = "FS", l = 2)
 #' S(S_hat); lags(S_hat)
@@ -109,6 +118,7 @@ transitP <- function(object) {
 }
 
 # ===== MTD obj methods =====
+# Most accessors for "MTD" also work for "MTDest" objects via inheritance
 
 #' @exportS3Method pj MTD
 pj.MTD <- function(object) {
@@ -125,16 +135,16 @@ lambdas.MTD <- function(object) {
   object$lambdas
 }
 
-#' @exportS3Method lags MTD
-lags.MTD <- function(object) {
-  -object$Lambda  # lags are in Z^-
-}
-
 #' @exportS3Method Lambda MTD
 Lambda.MTD <- function(object) {
   object$Lambda
 }
 
+#' @exportS3Method lags MTD
+lags.MTD <- function(object) {
+  -Lambda(object) # lags are in Z^-
+}
+
 #' @exportS3Method states MTD
 states.MTD <- function(object) {
   object$A
@@ -142,39 +152,30 @@ states.MTD <- function(object) {
 
 #' @exportS3Method transitP MTD
 transitP.MTD <- function(object) {
-  object$P
+   object$P
 }
 
 # ===== MTDest obj methods =====
 
-#' @exportS3Method pj MTDest
-pj.MTDest <- function(object) {
-  object$pj
-}
-
-#' @exportS3Method p0 MTDest
-p0.MTDest <- function(object) {
-  object$p0
-}
-
-#' @exportS3Method lambdas MTDest
-lambdas.MTDest <- function(object) {
-  object$lambdas
-}
-
-#' @exportS3Method lags MTDest
-lags.MTDest <- function(object) {
-  -object$S  # lags are in Z^-
-}
-
 #' @exportS3Method S MTDest
 S.MTDest <- function(object) {
   object$S
 }
 
-#' @exportS3Method states MTDest
-states.MTDest <- function(object) {
-  object$A
+#' @exportS3Method Lambda MTDest
+Lambda.MTDest <- function(object) {
+  object$S
+}
+
+#' @exportS3Method transitP MTDest
+transitP.MTDest <- function(object) {
+  compute_transitP( # see utils.R
+    Lambda  = object$S,
+    A       = object$A,
+    lambdas = object$lambdas,
+    pj      = object$pj,
+    p0      = object$p0
+  )
 }
 
 # ===== hdMTD obj methods =====
