@@ -1,27 +1,29 @@
 #' Oscillations of an MTD Markov chain
 #'
-#' Calculates the oscillations of an MTD model object or estimates the oscillations of a chain sample.
+#' Calculates the oscillations of an MTD model object, of an MTDest fit,
+#' or estimates the oscillations of a chain sample.
 #'
 #' @name oscillation
 #' @rdname oscillation
-#' @param x Must be an MTD object or a chain sample.
+#' @param x Either an MTD model object, an MTDest fit, or a chain sample.
 #' @param ... Ignored.
 #'
 #'
-#' @details For an MTD model, the oscillation for lag \eqn{j}
-#' ( \eqn{ \{ \delta_j:\ j \in \Lambda \} }), is the product of the weight \eqn{\lambda_j}
-#' multiplied by the maximum of the total variation distance between the distributions in a
-#' stochastic matrix \eqn{p_j}.
+#' @details For an MTD model or an MTDest fit, the oscillation for lag \eqn{j}
+#' (i.e., \eqn{ \{ \delta_j:\ j \in \Lambda \} } for MTD or \eqn{ \{ \delta_j:\ j \in S \} }
+#' for MTDest) is the product of the mixture weight \eqn{\lambda_j} and the
+#' maximum of the total variation distance between the distributions in a
+#' stochastic matrix \eqn{p_j}. That is,
 #' \deqn{\delta_j = \lambda_j\max_{b,c \in \mathcal{A}} d_{TV}(p_j(\cdot | b), p_j(\cdot | c)).}
-#' So, if \code{x} is an MTD object, the parameters \eqn{\Lambda}, \eqn{\mathcal{A}}, \eqn{\lambda_j},
-#' and \eqn{p_j} are inputted through, respectively, the entries \code{Lambda}, \code{A},
-#' \code{lambdas} and the list \code{pj} of stochastic matrices. Hence, an oscillation \eqn{\delta_j}
-#' may be calculated for all \eqn{j \in \Lambda}.
-#' For estimating the oscillations from a sample, then \code{x} must be a chain,
-#' and \code{S}, a vector representing a set of lags, must be informed. This way the transition
-#' probabilities can be estimated.
+#' When \code{x} is an object of class MTD (or MTDest), the quantities \eqn{\Lambda}
+#' (or \eqn{S}), \eqn{\mathcal{A}}, \eqn{\lambda_j}, and \eqn{p_j} are directly available.
+#' In this case, the oscillations can be computed exactly from the model parameters.
 #'
-#' @details Let \eqn{\hat{p}(\cdot| x_S)} symbolize an estimated distribution
+#' Alternatively, when estimating oscillations from data, \code{x} must be a
+#' realization of a chain and \code{S} must be provided as a candidate lag set.
+#' The transition probabilities are then estimated from the sample before
+#' computing the corresponding oscillations.
+#' Let \eqn{\hat{p}(\cdot| x_S)} symbolize an estimated distribution
 #' in \eqn{\mathcal{A}} given a certain past \eqn{x_S} ( which is a sequence of
 #' elements of \eqn{\mathcal{A}} where each element occurred at a lag in \code{S}),
 #' and \eqn{\hat{p}(\cdot|b_jx_S)} an estimated distribution given past \eqn{x_S}
@@ -34,12 +36,12 @@
 #' indexed by \code{S}.
 
 #' @return A named numeric vector of oscillations. If the \code{x} parameter is
-#' an MTD object, it will provide the oscillations for each element in \code{Lambda}.
-#' If \code{x} is a chain sample, it estimates the oscillations for a user-inputted
-#' set of lags \code{S}.
+#' an MTD or MTDest object, it will provide the oscillations for each element in
+#' \code{Lambda} (or \code{S} for MTDest). If \code{x} is a chain sample, it
+#' estimates the oscillations for a user-inputted set of lags \code{S}.
 #'
 #' @examples
-#' oscillation( MTDmodel(Lambda = c(1, 4), A = c(2, 3) ) )
+#' oscillation(MTDmodel(Lambda = c(1, 4), A = c(2, 3)))
 #' oscillation(MTDmodel(Lambda = c(1, 4), A = c(2, 3), lam0 = 0.01, lamj = c(0.49, 0.5),
 #'                       pj = list(matrix(c(0.1, 0.9, 0.9, 0.1), ncol = 2)),
 #'                       single_matrix = TRUE))
@@ -49,7 +51,8 @@
 #'
 oscillation <- function(x,...) {UseMethod("oscillation")}
 
-#' @describeIn oscillation For an \code{MTD} object: computes \eqn{\delta_j} for all \eqn{j \in \Lambda}.
+#' @describeIn oscillation For an \code{MTD} (or \code{MTDest}) object: computes
+#' \eqn{\delta_j} for all \eqn{j \in \Lambda} (or for all \eqn{j \in S}).
 #' @export
 oscillation.MTD <- function(x,...){
 
@@ -68,7 +71,7 @@ oscillation.MTD <- function(x,...){
 
   # For each j in Lambda, oscillation_j = \lambda_j * dTV_pj
   y <- x$lambdas[-1] * sapply(x$pj, dTV_pj, rows) # oscillations for each j
-  names(y) <- paste0("-", x$Lambda)
+  names(y) <- paste0("-", Lambda(x))
   y
 }
 
@@ -104,6 +107,7 @@ oscillation.default <- function(x, S, A = NULL, ...){
         if (lenS > 1) {
             Z <- setdiff(S, j) # Z <-  S\{j}
             b_S <- groupTab(S = Z, j = NULL, b_Sja, lenX = lenX, d = S[1])
+            # groupTab is defined at utils.R
             PositiveNx_S <- which(b_S$Nx_Sj > 0) # Positions of the x_Z that appeared in the sample
             subx <- b_S[PositiveNx_S, -lenS] # List of these x_Z
         } else {
