@@ -5,10 +5,9 @@
 # simple algorithm or calculation.
 
 # 1 - groupTab()
-# 2 - PI()
-# 3 - sx()
-# 4 - n_parameters()
-# 5 - fmt_vec()
+# 2 - n_parameters()
+# 3 - fmt_vec()
+# 4 - compute_transitP()
 
 # At the end of each auxiliary function below there is
 # a note naming the functions that use it.
@@ -53,86 +52,6 @@ groupTab <- function(S, j, freqTab, lenX, d){
 }
 # groupTab is used in: oscillation.R, hdMTD_FS.R.
 
-###########################################################
-###########################################################
-###########################################################
-
-# PI: Estimates the empirical stationary distribution for a given sequence.
-#
-# This function computes the stationary distribution for sequences stored in a
-# frequency table (`groupTab`). It filters sequences that match `x_S` in the
-# specified lags `S`, then normalizes their frequencies to estimate stationary
-# probabilities.
-#
-# Arguments:
-# - S: A numeric vector of past lags. Determines which columns in `groupTab` should
-#   be used for filtering.
-# - groupTab: A tibble containing sequence frequencies (`Nx_Sj` column).
-# - x_S: A vector representing a specific sequence of states in lags `S`.
-# - lenX: Sample size (integer).
-# - d: Maximum lag order (integer).
-#
-# Returns:
-# - A numeric matrix (column vector) with estimated stationary probabilities.
-#   The column name corresponds to the concatenated elements of `x_S`.
-
-PI <- function(S, groupTab, x_S, lenX, d) {
-
-    if (length(S) > 0) {
-        # Filters groupTab by x_S.
-        filtr_S <- paste0("x", S)
-        groupTab <- groupTab %>%
-            dplyr::mutate(match = purrr::pmap_lgl(dplyr::pick(dplyr::all_of(filtr_S)),
-                ~ all(c(...) == x_S))) %>%
-            dplyr::filter(match) %>%
-            dplyr::select(-match)
-    }
-    PI <- matrix(groupTab$Nx_Sj/(lenX-d),ncol = 1)
-    colnames(PI) <- "freq"
-    PI
-}
-# PI is used in hdMTD_FS.R.
-
-###########################################################
-###########################################################
-###########################################################
-
-# sx: Computes thresholds for the CUT method in MTD models
-#
-# This function calculates the threshold used in the CUT step of the MTD inference algorithm.
-# It computes a quantity that determines whether the variation in distributions across lagged states
-# is significant, based on the provided parameters `mu`, `alpha`, and `xi`.
-#
-# Arguments:
-# - S: A numeric vector of past lags. Determines which columns in `freqTab` should be used for filtering.
-# - freqTab: An output of freqTab() function, i.e. a tibble containing frequency counts
-#  (`Nx_Sj` column) and conditional probabilities (`qax_Sj`).
-# - lenA: The number of distinct states in the state space.
-# - x_S: A vector representing a specific sequence of states in lags `S`.
-# - mu: A positive real number between 0 and 3, influencing the threshold calculation.
-# - alpha: A positive real number controlling the sensitivity of the threshold.
-# - xi: A positive real number affecting the threshold scaling.
-#
-# Returns:
-# - A numeric vector of length `lenA`, where each entry represents the computed threshold
-# for a specific state.
-
-
-sx <- function(S, freqTab, lenA, x_S, mu, alpha, xi){
-    filtr_S <- paste0("x", S)
-    C <- freqTab %>%
-        dplyr::mutate(match = purrr::pmap_lgl(pick(all_of(filtr_S)), ~all(c(...) ==
-            x_S))) %>%
-        dplyr::filter(match) %>%
-        dplyr::select(-match)
-
-    Nx <- C$Nx_Sj[seq(1, nrow(C), by = lenA)]
-
-    prob_adjusted <- sqrt((C$qax_Sj + alpha/rep(Nx, each = lenA)) * mu/(2 * mu - exp(mu) + 1))
-    sum <- colSums(matrix(prob_adjusted, nrow = lenA))
-
-    return(sqrt(0.5 * alpha * (1 + xi)/Nx) * sum + alpha * lenA/(6 * Nx))
-} # sx is used in hdMTD_CUT.R.
 
 ###########################################################
 ###########################################################
@@ -176,7 +95,7 @@ n_parameters <- function(Lambda, A, single_matrix = FALSE, indep_part = TRUE, ze
     n_parameters <- n_parameters + lenA * (lenA - 1) * zeta
     # lenA*(lenA-1) is the number of free parameters in each matrix pj. zeta is the number of distinct matrices pj
     n_parameters
-} # n_parameters is used in hdMTD_BIC.R.
+} # n_parameters is used in hdMTD_BIC.R, MTDest-methods.R and MTDmodel-methods.R.
 
 
 ###########################################################
@@ -212,4 +131,83 @@ fmt_vec <- function(x, max_items = 10, digits = NULL, empty = "empty") {
     paste0(paste(x[seq_len(max_items)], collapse = ", "),
            ", ... (", n, " total)")
   }
-}# Used in: MTD-methods.R, hdMTD-methods.R
+}# Used in: MTD-methods.R, MTDest-methods.R and hdMTD-methods.R
+
+
+###########################################################
+###########################################################
+###########################################################
+
+# compute_transitP: Computes the global transition matrix of an MTD model
+#
+# This function constructs the global transition matrix P of an MTD model from
+# the model parameters. The matrix P has |A|^|Lambda| rows (past contexts) and
+# |A| columns (next-state values). Each row corresponds to a past context
+# (ordered from oldest to newest, matching the ordering of Lambda) and gives
+# the conditional distribution of the next state given that context.
+#
+# Arguments:
+# - Lambda: A numeric vector of positive integers representing the relevant lag set.
+#   The order of the elements must match the order of the list pj.
+# - A: A vector representing the state space. The columns of P are named by A.
+# - lambdas: Numeric vector of mixture weights of length length(Lambda) + 1.
+#   The first element is the weight of the independent component (p0), and the
+#   remaining elements correspond to each lag-specific transition matrix in pj.
+# - pj: List of row-stochastic matrices (one per lag in Lambda). Each matrix must be
+#   length(A) x length(A), with rows indexing the previous state and columns indexing
+#   the next state.
+# - p0: Numeric vector of length(A) giving the independent distribution on A. If the
+#   independent component is inactive, p0 should be a zero vector (typically with
+#   lambdas[1] = 0).
+#
+# Details:
+# The returned transition probabilities are given by
+#   P(a | x) = lambda_0 p0(a) + sum_{j in Lambda} lambda_j p_j(a | x_j),
+# where x = (x_j)_{j in Lambda} denotes the past context.
+#
+# Returns:
+# - A numeric matrix P with nrow(P) = length(A)^length(Lambda) and ncol(P) = length(A).
+# - Columns are named by A.
+# - If length(Lambda) > 1, row names encode past contexts by concatenating the values
+#   in A from oldest to newest.
+#
+# Notes:
+# - This function can be expensive when length(A)^length(Lambda) is large, since it
+#   enumerates all past contexts via expand.grid().
+compute_transitP <- function(Lambda, A, lambdas, pj, p0) {
+  lenL <- length(Lambda)
+  lenA <- length(A)
+  lenAL <- lenA^lenL
+
+  # Generate all possible size lenL sequences with digits from 1 to lenA
+  subx <- try(expand.grid(rep(list(seq_len(lenA)), lenL)), silent = TRUE)
+  if(inherits(subx,"try-error")) {
+    stop(paste0("For length(Lambda)=",lenL," the dataset with all pasts sequences (x of length(Lambda)) with elements of A is too large."))
+  }
+  subx <- subx[, order(lenL:1)]
+
+  P <- matrix(0, ncol = lenA, nrow = lenAL)
+
+  if (lenL == 1) {
+    for (i in seq_len(lenAL)) { # runs in all lines of P
+      P[i, ] <- lambdas %*% rbind(p0, pj[[1]][i, ])
+    }
+    rownames(P) <- A
+  } else {
+    for (i in seq_len(lenAL)) {
+      aux <- matrix(0, ncol = lenA, nrow = lenL)
+      for (j in seq_len(lenL)) {
+        aux[j, ] <- pj[[j]][subx[i, (lenL + 1 - j)], ]
+        # The lines in aux are each from a different pj
+      }
+      P[i, ] <- lambdas %*% rbind(p0, aux)
+    }
+  }
+  colnames(P) <- A
+  if(lenL > 1){
+    subx <- as.matrix(expand.grid(rep(list(A), lenL))) # Elements from A
+    subx <- subx[, order(lenL:1)]
+    rownames(P) <- apply(subx, 1, paste0, collapse = "")
+  }
+  return(P)
+}  # Used in: MTDmodel.R and accessors.R - transitP().
